% A script to calculate:
% forecasts
% actuals
% PITs
% Predictive Likelihood
% for all variables and methods

% results:
% Object ALLfct

clear all
clc
format compact

addpath('MatlabUtils');

modelNames = [{'RW'} {'RWdrift'} {'BAR'} {'BARfixed'} {'DBVAR'} {'LBVAR'} {'MBVAR'} {'KilianVAR'} {'KilianBVAR'} {'NPtrend'} {'NPntrend'}];

M  = size(modelNames,2);
H  = 20;                    % forecast horizon
T  = 139;                   % total number of observations
T0 = 96;                    % observation for 2009q1 
varnames = [{'oil_obs'}];

N  = size(varnames,2);      % number of variables

% loads actuals    
load(['NPdata']);    
for mN=1:M
    display(modelNames{mN})
    mName = modelNames{mN};
        
    % initializes matrices for growth rates and levels
    for n = 1:N
        vnm = varnames{n};
        eval(['ALLtemp.',vnm,'.act    = NaN(T-T0,H);'])
        eval(['ALLtemp.',vnm,'.fct    = NaN(T-T0,H);']) % Adolfson method
        eval(['ALLtemp.',vnm,'.pit    = NaN(T-T0,H);'])
        eval(['ALLtemp.',vnm,'.pLL    = NaN(T-T0,H);'])
    end
    
    % main loop for each periods generates draws and calculates forecasts,
    % actuals, predictive Likelihhod and PITs
    
    for dates = (2007.75):(0.25):(2018.25)
        i = floor(dates);           % year
        j = 1 + (dates - i)*4;      % quarter
                        
        Tf    = T0 + 4*(i-2007) + (j-4) ;                                % moment of forecast formulation
        fname = [mName,'/NPest/',num2str(i),'q',num2str(j),'/forecasts.mat'];  
        load(fname);                                                  % loads forecast draws  
                
        % individual variables
        for n = 1:N 
            vnm = varnames{n};
            
            act  = NaN(1,H); % actuals
            pit  = NaN(1,H); % PIT, Adolfson
            pLL  = NaN(1,H); % predictive scores, Adolfson
            
            eval(['draws=f.',vnm,';']);         % forecast draws             
            fct      = (mean(draws,2))';        % point forecasts (mean), Adolfson
                        
            % check if actuals exists and calculate actuals
            Hf    = min(H,T-Tf);
            eval(['act(1:Hf)=',vnm,'((Tf+1):(Tf+Hf));']); 
            if n ~= 3 % n==3 for R_obs
                act = cumsum(act);
            end
            
            % calculate PIT and predictive density
            for h = 1:Hf
                pit(h)       = PIT(draws(h,:),act(h));
                pLL(h)       = PredLL(draws(h,:),act(h));
            end
                 
            % Saves results          
            eval(['ALLtemp.',vnm,'.act(Tf-T0+1,:)    = act;'])
            eval(['ALLtemp.',vnm,'.fct(Tf-T0+1,:)    = fct;'])
            eval(['ALLtemp.',vnm,'.pLL(Tf-T0+1,:)    = pLL;'])
            eval(['ALLtemp.',vnm,'.pit(Tf-T0+1,:)    = pit;'])
        end    
end
    
ALLfct{mN} = ALLtemp;   
ALLfct{mN}.mName = mName;
end

% Equally weighted forecasts
ALLfct{M+1}.oil_obs.act = ALLfct{1}.oil_obs.act;
ALLfct{M+1}.oil_obs.fct = 0;
ALLfct{M+1}.oil_obs.pit = 0;
ALLfct{M+1}.oil_obs.pLL = 0;
for mN=1:M
    ALLfct{M+1}.oil_obs.fct = ALLfct{M+1}.oil_obs.fct + 1/M*ALLfct{mN}.oil_obs.fct;
    ALLfct{M+1}.oil_obs.pit = ALLfct{M+1}.oil_obs.pit + 1/M*ALLfct{mN}.oil_obs.pit;
    ALLfct{M+1}.oil_obs.pLL = ALLfct{M+1}.oil_obs.pLL + 1/M*log(ALLfct{mN}.oil_obs.pLL);
end
ALLfct{M+1}.mName = 'Pooled';
ALLfct{M+1}.oil_obs.pLL = exp(ALLfct{M+1}.oil_obs.pLL);

save(['ALLfct.mat'], 'ALLfct');   