% File to calculate statistics for point forecasts

clear all
clc
format compact
load('ALLfct.mat')

modelNames = [{'RW'} {'RWdrift'} {'BAR'} {'BARfixed'} {'DBVAR'} {'LBVAR'} {'MBVAR'} {'KilianVAR'} {'KilianBVAR'} {'NPtrend'} {'NPntrend'} {'Pool'}];
varnames = [{'oil_obs'}];

M  = size(modelNames,2); % number of models
H  = 20;
bM = 1;                  % benchmark model

vnm     = 'oil_obs';
ME      = NaN(M,H);
MEp     = NaN(M,H);
RMSE    = NaN(M,H);
RMSEp   = NaN(M,H);
    
for mN = 1:M % loop for models
    eval(['fct  = ALLfct{1,mN}.', vnm ,'.fct;'])   % Adolfson et al..
    eval(['fct0 = ALLfct{1,bM}.', vnm ,'.fct;'])   % benchmark 
    eval(['act  = ALLfct{1,mN}.', vnm ,'.act;'])   % actuals
             
    err  = act - fct;
    err0 = act - fct0;            % forecast errors
    
    % statistics
    ME(mN,:)     = nanmean(err);
    RMSE(mN,:)   = sqrt(nanmean(err.^2));
    % Unbiasedness test for HO: ME(h)=0
    for h = 1:H
        x          = err(:,h); x = x(find(~isnan(x)));
        temp       = NeweyWestSE(x);
        MEp(mN,h)  = temp.prob;
    end
    % Diebold-Mariano for HO: equal predictive  accuracy
    for h = 1:H
        a          = act(:,h);             
        f0         = fct0(:,h); f0 = f0(find(~isnan(a)));
        f1         = fct(:,h);  f1 = f1(find(~isnan(a)));  
        a          = a(find(~isnan(a))); 
        temp       = DMtest(f0, f1, a, 0, 1, 2); % foth argument 1 for Iacone Coroneo, 5 arg 1 for CW, 6 arg - power
        RMSEp(mN,h) = temp.prob;
    end
end 

horiz = [1 2 4 6 8 12 16 20];
    
filename = ['stats'];
    
xlswrite(filename, {'Mean Error'},           'ME', 'A1');
xlswrite(filename, horiz         ,           'ME', 'B1');
xlswrite(filename, modelNames'  ,            'ME', 'A2');
xlswrite(filename, ME(:,horiz)   ,           'ME', 'B2');
xlswrite(filename, {'Mean Error prob'},      'ME', 'K1');
xlswrite(filename, horiz         ,           'ME', 'L1');
xlswrite(filename, modelNames'  ,            'ME', 'K2');
xlswrite(filename, MEp(:,horiz)      ,       'ME', 'L2');
    
xlswrite(filename, {'RMSE'},                 'RMSE', 'A1');
xlswrite(filename, horiz         ,           'RMSE', 'B1');
xlswrite(filename, modelNames'  ,            'RMSE', 'A2');
xlswrite(filename, RMSE(:,horiz)      ,      'RMSE', 'B2');
    
xlswrite(filename, {'DM prob'},              'RMSE', 'K1');
xlswrite(filename, horiz         ,           'RMSE', 'L1');
xlswrite(filename, modelNames'  ,            'RMSE', 'K2');
xlswrite(filename, RMSEp(:,horiz)      ,     'RMSE', 'L2');
    


