% File to calculate statistics for density forecasts

clear all
clc
format compact
load('ALLfct.mat')

modelNames = [{'RW'} {'RWdrift'} {'BAR'} {'BARfixed'} {'DBVAR'} {'LBVAR'} {'MBVAR'} {'KilianVAR'} {'KilianBVAR'} {'NPtrend'} {'NPntrend'} {'Pool'}];
varnames = [{'oil_obs'}];

M  = size(modelNames,2); % number of models
H  = 20;
bM = 1;                  % benchmark model

vnm     = 'oil_obs';
PredLL      = NaN(M,H);
PredLLp     = NaN(M,H);
    
for mN = 1:M % loop for models
    eval(['pLL  = ALLfct{1,mN}.', vnm ,'.pLL;']) 
    eval(['pLL0 = ALLfct{1,bM}.', vnm ,'.pLL;'])  % benchmark
  
    % statistics
    PredLL(mN,:)     = nanmean(log(pLL));
    % Amisano-Giacomini test for HO: equal predictive accuracy
    for h = 1:H
        temp          = GAtest(pLL0(:,h),pLL(:,h));
        PredLLp(mN,h) = temp.prob; 
    end
end

horiz = [1 2 4 6 8 12 16 20];
    
filename = ['stats'];
    
xlswrite(filename, {'LPS'},                  'LPS', 'A1');
xlswrite(filename, horiz         ,           'LPS', 'B1');
xlswrite(filename, modelNames'  ,            'LPS', 'A2');
xlswrite(filename, PredLL(:,horiz)      ,      'LPS', 'B2');
    
xlswrite(filename, {'GA prob'},              'LPS', 'K1');
xlswrite(filename, horiz         ,           'LPS', 'L1');
xlswrite(filename, modelNames'  ,            'LPS', 'K2');
xlswrite(filename, PredLLp(:,horiz)      ,   'LPS', 'L2');

