close all
clear all
clc
format compact
load('ALLfct.mat')

load NPdata;
y      = cumsum(oil_obs);  % observable
ylevel = exp(y/100);

% rescaling so that prioces are expressed in 2018Q3 USD
resY   = 69.757 / ylevel(139);
ylevel = ylevel*resY;

E      = 96;                      % size of estimation sample
evs    = 43;                      % size of evaluation sample
H      = 20;                      % forecast horizon

modelNames = [{'RW'} {'RWdrift'} {'BAR'} {'AR-fixed'} {'DBVAR'} {'LBVAR'} {'MBVAR'} {'KVAR'} {'KBVAR'} {'DSGEt'} {'DSGE'} {'Pool'}];
varnames = [{'oil_obs'}];
mSet  = [2 3 4 5 6 8 10 11 12];

y_lim = [10 200];

n = 0;

figure('Name','Real oil whiskers','Color',[1 1 1]);

for mN = mSet % loop for countries
    n = n+1; % counter
    subplot(3,3,n)
    if (n>3 && n<7)
        y_lim = [10 250];
    else
        y_lim = [10 200];
    end   
    
    % Generating forecast and past actuals
        temp  = ALLfct{1, mN}.oil_obs.fct;
        q_fct = NaN(evs,E+evs+H);

        for i=1:evs
            q_fct(i,1:E+i-1)     = y(1:1:E+i-1);
            q_fct(i,E+i:E+i+H-1) = temp(i,1:H) + y(E+i-1);
        end
        q_fct = exp(q_fct/100)*resY;
        
        plot(1984:0.25:2023.50,q_fct,'Color',[0.5 0.5 0.5]); 
        title(modelNames{mN}); 
        ylim(y_lim); 
        xlim([2000 2022]); 
        hold on;
      
        plot(1984:0.25:2018.5,ylevel,'-k','LineWidth',2); hold off;
        set(gca, 'XTick', [2000 2010 2020])
        box('off')
end
    
   
    

 