clear
clc
format compact
close all
load(['Allfct']);
load(['NPdata']);   % loads history of data
y      = cumsum(oil_obs);  % observable
ylevel = exp(y/100);

% rescaling so that prioces are expressed in 2018Q3 USD
resY   = 69.757 / ylevel(139);
ylevel = ylevel*resY;

Hf = 8;                   % history of data
H  = 8;                   % forecast horizon
% i =2008; j=2; y_lim = [40 800];
% i =2009; j=1; y_lim = [10 160];
i  = 2014; j  = 2; y_lim = [30 300];
Tf = 96 + 4*(i-2007) + (j-4);
varnames = {'oil_obs'}; 
N        = 1;
modelNames1 = [{'RW'} {'RWdrift'} {'BAR'} {'AR-fixed'} {'DBVAR'} {'LBVAR'} {'MBVAR'} {'KVAR'} {'KBVAR'} {'DSGEt'} {'DSGE'} {'Pool'}];
modelNames  = [{'RW'} {'RWdrift'} {'BAR'} {'BARfixed'} {'DBVAR'} {'LBVAR'} {'MBVAR'} {'KilianVAR'} {'KilianBVAR'} {'NPtrend'} {'NPntrend'}];
mSet  = [1 4 5 8 10 11];

figure1  = figure('Color',[1 1 1]);

n = 0;
for m = mSet;
    n = n+1;
    model = modelNames{m};
    fname = [model,'/NPest/',num2str(i),'q',num2str(j),'/forecasts.mat'];  
    load(fname);                                                  % loads forecast draws  
    draws=f.oil_obs; 
    draws = exp((y(Tf)+ draws)/100)*resY; 

     
    % Fancharts
    act  = ylevel(Tf-Hf+1:Tf+H);
    hist = act(1:Hf);

    % Set relevant quantiles (in percent)
    quantiles=[1 5 10 15 20 25 30 35 40 50 60 65 70 75 80 85 90 95 99];
    mat_quant=NaN(H,19);
    for h=1:H % loop over horizon
        for q=1:19 % loop over quantiles
            mat_quant(h,q)=quantile(draws(h,:),quantiles(1,q)/100);
        end
    end

    % Add hist. observations to the plot matrix
    addv=[10^(-42) 10^(-43) 10^(-44) 10^(-45) 10^(-46) 10^(-47) 10^(-48) 10^(-49) 10^(-50) 0 10^(-50) 10^(-49) 10^(-48) 10^(-47) 10^(-46) 10^(-45) 10^(-44) 10^(-43) 10^(-42)];
    hm=hist;
    for ii=1:18
        hm=[hm hist]; %#ok<AGROW>
    end
    mat_quant=[hm;mat_quant];
    for t=1:Hf
        mat_quant(t,:)=mat_quant(t,:)+addv; 
    end

    % Prepare plot matrix for its use with the area function
    matm=mat_quant;
    for ii=2:size(matm,2)
        matm(:,ii)=matm(:,ii)-mat_quant(:,ii-1);
    end
    %matm(:,1) = act;

    %ToChart{m,n}.matm = matm;
    %ToChart{m,n}.act  = act;

    % Generate plot
    %figure1  = figure('Color',[1 1 1]);
    subplot1 = subplot(3,2,n,'Parent',figure1);
    hold(subplot1,'all');


    h=area(matm, 'LineStyle','none');
    r=0.5;
    b=0.5;
    set(h,'LineStyle','none')
    set(h(1),'FaceColor',[1 1 1]) % white
    set(h(2),'FaceColor',[r .99 b])
    set(h(3),'FaceColor',[r .975 b])
    set(h(4),'FaceColor',[r .95 b])
    set(h(5),'FaceColor',[r .9 b])
    set(h(6),'FaceColor',[r .85 b])
    set(h(7),'FaceColor',[r .8 b])
    set(h(8),'FaceColor',[r .75 b])
    set(h(9),'FaceColor',[r .7 b])
    set(h(10),'FaceColor',[r .65 b]) %
    set(h(11),'FaceColor',[r .65 b])%
    set(h(12),'FaceColor',[r .7 b])
    set(h(13),'FaceColor',[r .75 b])
    set(h(14),'FaceColor',[r .8 b])
    set(h(15),'FaceColor',[r .85 b])
    set(h(16),'FaceColor',[r .9 b])
    set(h(17),'FaceColor',[r .95 b])
    set(h(18),'FaceColor',[r .975 b])
    set(h(19),'FaceColor',[r .99 b])
    hold on
    plot(act,'LineWidth',3,'Color',[0 0 0]);  % median forecast in black
    set(gcf,'Color','w')
    set(gca, 'YScale', 'log')
    ylim(y_lim);
    %set(gca,'XTick',[])
    set(gca,'YTick',[5 10 20 50 100 200 400 800])
    set(gca,'YTickLabel',{'5' '10' '20' '50','100','200', '400', '800'})
    set(gca,'XTick',[1  Hf  Hf+H])
    set(gca,'XTickLabel',num2str(floor(date([Tf-Hf+1 Tf Tf+H]))));
    title(modelNames1{m})
end
        
           