clear all
format compact 
format short

addpath('files');

for itr = 1:43
    j = mod(2+itr,4)+1;
    i = 2007 + floor((itr+2)/4);
    nobs = 96 + 4*(i-2007) + (j-4);
    load('NPdata');
       
    oil     = cumsum(oil_obs);
    data    = [y_obs p_obs R_obs oil];
    data    = data(1:nobs,:); oil = oil(1:nobs);
       
    % Mean adjusted BVAR settings
    const = 1;
    lags  = 4; 
    ar    = [0; 0; 0.9; 0.9]; %  Minnesota auto-regressive coefficient of each variable on its own first lag
    lambda1   = 0.2;    %overall tightness
    lambda2   = 0.5;    %cross-variable variance parameter
    lambda3   = 1;      %lag decay
    lambda4   = 100;    %exogenous variables, not important here
    lambda5   = 0.001;  %variance parameter on block exogenous variables, not important here
    Fpconfint = [{[0.25 0.75]};      % Quarterly GDP growth  - y_obs (annual 1-3)
                 {[0.25 0.75]};      % Quarterly inflation   - p_obs (annual 1-3)
                 {[2 6]};      % Interest rate         - i_obs (annual 3-5)
                 {[mean(oil)-5 mean(oil)+5]};         % real oil price - mean(oil)
                    {[-1.5 1.5 ]};     % current account       - ca_obs
                    {[0.25 0.75]};     % Quarterly GDP growth  - y_s_obs 
                    {[0.25 0.75]};     % Quarterly inflation   - p_s_obs
                    {[0.75 1.25]}      % Interest rate         - i_s_obs
                    ];          % steady state priors - 95% interval
    % Gibbs sampling setting
    It = 60000; % the total number of iterations run by the Gibbs sampler
    Bu = 10000; % the number of initial iterations discared as burn-in sample
    % Forecast setting
    H  = 20;  % Forecast horizon 
       
    [fct, psi_gibbs]= forecastdraws(data, const, lags, It, Bu, ar, lambda1, lambda2, lambda3, lambda4, lambda5, Fpconfint, H);
       
    f.oil_obs     = fct{4,1}' - oil(nobs);
    f.oil_ss      = mean(psi_gibbs(4,:)'); % posterior steady state for q;
       
    if ~isdir(['NPest/',num2str(i),'q',num2str(j)])
       mkdir(['NPest/',num2str(i),'q',num2str(j)]);
    end
    save(['NPest/',num2str(i),'q',num2str(j),'/forecasts.mat'],'f');  
       
end


% y = [y_s_obs p_s_obs i_s_obs y_obs p_obs i_obs q_obs ca_obs];
