function [f, psi_gibbs]= forecastdraws(data, const, lags, It, Bu, ar, lambda1, lambda2, lambda3, lambda4, lambda5, Fpconfint, H)

%data  = [q p_obs i_obs];
% model specification setting
%const = 1;
%lags  = 4; 
% prior specification
%ar        = [0.9; 0.0; 0.9];   Minnesota auto-regressive coefficient of each variable on its own first lag
%lambda1   = 0.1;    overall tightness
%lambda2   = 0.5;    cross-variable variance parameter
%lambda3   = 1;      lag decay
%lambda4   = 100;    exogenous variables
%lambda5   = 0.001; 'variance parameter on block exogenous variables
%Fpconfint = [{[-10 10]};{[0 5]};{[0 10]}]; containing the prior confidence intervals for the coefficients on exogenous data
% Gibbs sampling setting
% It  the total number of iterations run by the Gibbs sampler
% Bu  the number of initial iterations discared as burn-in sample
% Forecast setting
% H   Forecast horizon           
                   
% generate matrices Y X and Z as in (3.3.6.9)
[Y, X, Z, n, m, p, T, k1, k3, q1, q2, q3]= maprelim(data,[],const,lags);

% variance from estimated AR(p) models
[arvar]=arloop(data,const,lags,n);

% setting the prior
% beta0 and omega0 - prior for beta
% psi0 and lambda0 - prior for psi 
[beta0, omega0, psi0, lambda0]=maprior(ar,arvar,lambda1,lambda2,lambda3,lambda4,lambda5,n,m,p,k1,q1,q2,0,[],Fpconfint);

% run Gibbs sampler for estimation

[beta_gibbs, psi_gibbs, sigma_gibbs, delta_gibbs, ss_record]=magibbs(data,[],It,Bu,beta0,omega0,psi0,lambda0,Y,X,Z,n,m,T,k1,k3,q1,q2,q3,p);
% 'beta_gibbs': the matrix recording the post-burn draws of beta
% 'psi_gibbs': the matrix recording the post-burn draws of psi
% 'sigma_gibbs': the matrix recording the post-burn draws of sigma (nxn covariance matrix)
% 'delta_gibbs': the matrix recording the post-burn draws of delta (see p. 149, 3.3.6.12)
% 'ss_record': the cell storing the post-burn steady-state values

f = maforecast(data,[],[],It,Bu,beta_gibbs,sigma_gibbs,delta_gibbs,H,n,m,p,k1,k3);

%{
% checking for explosive roots
Z0 = zeros(n,n);
roots = NaN(k1,It-Bu); % roots for draws ...
for i = 1:(It-Bu)
    [evects,roots(:,i)] = eigen([reshape(beta_gibbs(:,i),k1,n)'; eye(n) Z0 Z0 Z0; Z0 eye(n) Z0 Z0; Z0 Z0 eye(n) Z0]);
end

% compute posterior estimates
%cband = 0.95; % confidence level for VAR coefficients
%[beta_median beta_std beta_lbound beta_ubound psi_median psi_std psi_lbound psi_ubound sigma_median]=maestimates(beta_gibbs,psi_gibbs,sigma_gibbs,cband,q1,q2,n);

f = NaN(H,n,It-Bu); % forecasts are stored
% forecasts
%H       = 10;                                   % Forecast horizon

for itr = 1:(It-Bu);

B       = reshape(beta_gibbs(:,itr),k1,n)';      % B matrix
psi     = psi_gibbs(:,itr);                       % psi vector
Sigma   = reshape(sigma_gibbs(:,itr),n,n);       %
SigC    = chol(Sigma)';
Y0      = Y(end-p+1:end,:) - ones(p,1) * psi';  % data after demaning, p last observations
X0      = lagx(Y0,p-1); 
for h = 1:H
    Yf = B*X0'+SigC*(mvnrnd(zeros(n,1),eye(n)))'; %forecast for demeaned series
    f(h,:,itr) = Yf + psi;
    Y0  = [Y0(2:end,:); Yf'];
    X0  = lagx(Y0,p-1); 
end

end
%}
