function res  = GAtest(pLL0, pLL1, CI)

% pLL0, pLL1 - predictive density from benchmark and M1
% act    - actuals  
% one sided test
% H0: M0 is true (for Clark-West)
% H0: e0^2 = e1^2 --> d=0
% H1: e0^2 > e1^2 --> d>0
% CI = 1: Coroneo-Iacone (2018)
if nargin == 2
    CI    = 0;
end


p0  = log(pLL0);
p1  = log(pLL1);
d   = p0 - p1;
d   = d(~isnan(d));

T   = length(d);
% long run matrix
X      = ones(T,1);
u      = d - X * mean(d);
if CI == 1
    % Coroneo-Iacone (2018) Comparing predictive accuracy in small samples using fixed smoothing asymptotics, JAE
    % method based on periodogram
    m  = floor(T^(1/3));
    % calculating periodogram
    Tspec = floor(T/2);
    freq  = 1/T:1/T:(Tspec/T);
    % fast furier transform
    xfft = zeros(T,1);
    for t=1:T
      for s=1:T
        xfft(t) = xfft(t) + u(s)*exp(-1i*2*pi*(t-1)*(s-1)/T);
      end
    end
    pgram  = real(xfft .* conj(xfft)/T);
    pgram  = pgram(2:(Tspec + 1));
    Sig  = mean(pgram(1:m));
    k    = 2*m;
else
    % Newey-West bandwidth method
    k      = T-1;
    nlags  = floor(4*(T/100)^(2/9)); 
    Sig    = 0;                         % Inicialization of covariance matrix
    for ii = 0:nlags
        w = 1 - (ii/(nlags+1));
        rho = u(1:T-ii,:)'*u(1+ii:T,:)/(T-1);  
        if ii >= 1, rho = 2*rho; end
        Sig = Sig + w*rho;  
    end
   
end
Se        = sqrt(Sig/T);
% one sided test
tstat     = mean(d)/Se;          res.stat = tstat;
prob      = tcdf(tstat,k);       res.prob = prob;    

