
% This program computes the forecast accuracy statistics based on Pesaran and Timmerman's (1992)
% directional accuracy test statistic for forecasts that do not rely on regression methods. It returns the
% success ratio and the asymptotic p-value of the test statistic.

function [freq,pval]=SignTest(act,fct,type)

if nargin == 2
    type = 0;
end

% Inputs
% act = vector actuals 
% fct = vector of forecasts
% type - type of test
%   0 - based on Hausman type of test with Normal distribution
%   1 - Goodness of fit test based on chi2

n = rows(act);
    
pxhat       = mean(sign(fct)>0);
pyhat       = mean(sign(act)>0);
phat        = mean(sign(act)==sign(fct));         % sample frequency
phatstar    = pxhat*pyhat + (1-pxhat)*(1-pyhat); %frequency if independently distr.
    
vphat     = phatstar*(1-phatstar)/n;
vphatstar = (pxhat*(1-pxhat)*(2*pyhat-1)^2)/n+(pyhat*(1-pyhat)*(2*pxhat-1)^2)/n+4*pyhat*pxhat*(1-pyhat)*(1-pxhat)/n^2;
    
freq = phat; % sample frequency
    
if ((vphat - vphatstar) ~= 0)
    da = (phat-phatstar)/sqrt(vphat-vphatstar);
    pval = 2*(1 - normcdf(abs(da),0,1));
else
    pval = 'NA. This model generates forecasts in one direction only.';
end;

% goodness of fit version
if type == 1
    p11 = sum((sign(fct)>0) .* (sign(act)>0))/n;
    p12 = sum((sign(fct)>0) .* (sign(act)<=0))/n;
    p21 = sum((sign(fct)<=0) .* (sign(act)>0))/n;
    p22 = sum((sign(fct)<=0) .* (sign(act)<=0))/n;
    p10 = sum(sign(fct)>0)/n;
    p20 = sum(sign(fct)<=0)/n;
    p01 = sum(sign(act)>0)/n;
    p02 = sum(sign(act)<=0)/n;

    stat = (p11 - p10*p01)^2/(p10*p01) + (p12 - p10*p02)^2/(p10*p02) + (p21 - p20*p01)^2/(p20*p01) + (p22 - p20*p02)^2/(p20*p02);
    stat  = n*stat;
    pval = 1-chi2cdf(stat,1);
end