function [residual, g1, g2, g3] = NPmodel_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(45, 1);
phi_p__ = params(12)*(1-params(16));
phi_y__ = (1-params(16))*params(14);
phi_yg__ = (1-params(16))*params(41);
phi_o__ = (1-params(16))*params(13);
phi_oc__ = (1-params(16))*params(42);
T71 = y(26)^params(11);
T84 = y(25)*params(7)*y(33)*exp(y(67))/y(61)/exp(y(58));
T98 = params(7)*params(8)*params(18)*y(64)^(params(9)-1);
T111 = params(7)*params(8)*y(64)^params(9);
T117 = y(32)/params(18);
T121 = y(29)/y(28);
T129 = params(8)*T117^params(9);
T156 = params(35)^params(6);
T157 = exp(y(54))*y(26)^params(5)*T156;
T158 = (y(27)+y(23))^(1-params(5)-params(6));
T268 = y(32)^(params(9)-1);
T275 = y(29)^(1-params(9));
T276 = (params(9)-1)*(1-params(8))*y(47)*T275;
T278 = y(28)^(params(9)-2);
T284 = y(29)^(-params(9));
T286 = y(28)^(params(9)-1);
T293 = y(32)^params(9);
T302 = y(29)^((-params(9))-1);
T303 = params(9)*(1-params(8))*y(48)*T302;
T304 = y(28)^params(9);
T317 = y(26)^(params(11)-1);
T322 = y(30)-1/exp(y(55));
T332 = params(4)*params(40)*exp(y(56))*exp(y(55))*y(34)*y(24)*(1-params(5)-params(6))*y(51)/(y(27)+y(23));
T343 = y(32)^2;
T347 = y(32)^(params(9)-2);
T359 = params(18)^(1-params(9));
T364 = params(18)^(-params(9));
T365 = params(9)*params(8)*y(48)*T364;
T376 = (y(64)/params(18))^params(9);
T420 = T156*exp(y(54))*params(36)^params(5);
T422 = T420*(y(41)+y(40))^(1-params(5)-params(6));
lhs =y(14);
rhs =log(y(25))-y(26)^(1+params(11))/(1+params(11))+params(7)*y(59);
residual(1)= lhs-rhs;
lhs =y(15);
rhs =log(y(27)*(y(30)-y(42)))+params(7)*y(60);
residual(2)= lhs-rhs;
lhs =y(16);
rhs =y(30)/y(42);
residual(3)= lhs-rhs;
lhs =y(22);
rhs =y(27)/(y(27)+y(23));
residual(4)= lhs-rhs;
lhs =y(23);
rhs =params(4)*(y(30)*exp(y(55))-params(3))*exp(y(56))*params(40);
residual(5)= lhs-rhs;
lhs =y(25);
rhs =y(24)-y(30)*(y(27)+y(23));
residual(6)= lhs-rhs;
lhs =y(31);
rhs =y(25)*T71;
residual(7)= lhs-rhs;
lhs =1;
rhs =T84/y(64);
residual(8)= lhs-rhs;
lhs =y(28);
rhs =y(24)*exp(y(58))/y(25)+T98*y(62);
residual(9)= lhs-rhs;
lhs =y(29);
rhs =y(24)*exp(y(58))*params(10)*y(35)/y(25)+T111*y(63);
residual(10)= lhs-rhs;
lhs =1;
rhs =params(8)*T117^(params(9)-1)+(1-params(8))*T121^(1-params(9));
residual(11)= lhs-rhs;
lhs =y(34);
rhs =T129*y(4)+(1-params(8))*T121^(-params(9));
residual(12)= lhs-rhs;
lhs =y(30)*(y(27)+y(23));
rhs =y(34)*y(24)*y(35)*(1-params(5)-params(6));
residual(13)= lhs-rhs;
lhs =y(26)*y(31);
rhs =y(34)*y(24)*y(35)*params(5);
residual(14)= lhs-rhs;
lhs =y(24)*y(34);
rhs =T157*T158;
residual(15)= lhs-rhs;
lhs =params(15)*(y(33)-params(17));
rhs =params(16)*params(15)*(y(3)-params(17))+(y(32)-1)*phi_p__+(y(25)-y(38)-(y(1)-y(5)))*phi_y__+(y(25)/y(38)-params(31))*phi_yg__+(y(30)-params(29))*phi_o__+(y(30)-y(2))*phi_oc__+y(57);
residual(16)= lhs-rhs;
lhs =0;
rhs =1/y(27)-y(30)*y(43)-y(30)*y(49)+y(34)*y(24)*(1-params(5)-params(6))*y(51)/(y(27)+y(23));
residual(17)= lhs-rhs;
lhs =0;
rhs =y(25)*(-y(43))+y(44)-y(1)*y(3)*y(6)/y(25)/y(32)-y(24)*y(45)-y(24)*y(35)*params(10)*y(46)+y(31)*y(52)+y(25)*phi_y__*(y(53)-params(7)*y(66))+y(25)*phi_yg__*y(53)/y(38);
residual(18)= lhs-rhs;
lhs =0;
rhs =y(43)+exp(y(58))*y(45)+exp(y(58))*y(35)*params(10)*y(46)+y(34)*y(35)*(1-params(5)-params(6))*y(49)-y(34)*y(35)*params(5)*y(50)-y(34)*y(51);
residual(19)= lhs-rhs;
lhs =0;
rhs =y(1)*params(18)*params(8)*y(7)*T268-y(25)*y(45)+T276*T278+params(9)*(1-params(8))*y(48)*T284*T286;
residual(20)= lhs-rhs;
lhs =0;
rhs =y(1)*params(8)*y(8)*T293-y(25)*y(46)+T286*T284*(1-params(9))*(1-params(8))*y(47)-T303*T304;
residual(21)= lhs-rhs;
lhs =0;
rhs =y(31)*y(50)+y(34)*y(24)*params(5)*y(51)/y(26)+params(11)*y(25)*y(52)*T317;
residual(22)= lhs-rhs;
lhs =0;
rhs =1/T322-(y(27)+2*y(23))*(y(43)+y(49))+T332+phi_o__*y(53)+phi_oc__*(y(53)-params(7)*y(66));
residual(23)= lhs-rhs;
lhs =0;
rhs =y(1)*y(3)*(-y(6))/y(25)/T343+y(28)*y(1)*(params(9)-1)*params(18)*params(8)*y(7)*T347+y(29)*T268*y(1)*params(9)*params(8)*y(8)+T347*(params(9)-1)*params(8)*y(47)*T359+y(4)*T268*T365+phi_p__*y(53);
residual(24)= lhs-rhs;
lhs =0;
rhs =params(8)*params(7)*y(65)*T376-y(48)+y(24)*y(35)*(1-params(5)-params(6))*y(49)-y(24)*y(35)*params(5)*y(50)-y(24)*y(51);
residual(25)= lhs-rhs;
lhs =0;
rhs =exp(y(58))*params(10)*y(46)+y(34)*(1-params(5)-params(6))*y(49)-y(34)*params(5)*y(50);
residual(26)= lhs-rhs;
lhs =0;
rhs =y(44)/y(33)-params(15)*(y(53)-y(66)*params(16)*params(7));
residual(27)= lhs-rhs;
lhs =0;
rhs =y(26)*y(50)-y(52);
residual(28)= lhs-rhs;
lhs =y(41);
rhs =params(40)*exp(y(56))*params(4)*(y(42)*exp(y(55))-params(3));
residual(29)= lhs-rhs;
lhs =y(42)*(y(41)+y(40));
rhs =(1-params(5)-params(6))/params(10)*y(37);
residual(30)= lhs-rhs;
lhs =y(42);
rhs =1/exp(y(55));
residual(31)= lhs-rhs;
lhs =y(37);
rhs =T422;
residual(32)= lhs-rhs;
lhs =y(38);
rhs =y(37)*(1-(1-params(5)-params(6))/params(10));
residual(33)= lhs-rhs;
lhs =y(36);
rhs =y(24)/y(37);
residual(34)= lhs-rhs;
lhs =y(39);
rhs =y(25)/y(38);
residual(35)= lhs-rhs;
lhs =y(54);
rhs =params(19)*y(9)+0.01*params(24)*x(it_, 1);
residual(36)= lhs-rhs;
lhs =y(55);
rhs =params(20)*y(10)-0.01*params(26)*x(it_, 2);
residual(37)= lhs-rhs;
lhs =y(56);
rhs =params(22)*y(11)-0.01*params(27)*x(it_, 3);
residual(38)= lhs-rhs;
lhs =y(57);
rhs =params(23)*y(12)-0.01*params(28)*x(it_, 4);
residual(39)= lhs-rhs;
lhs =y(58);
rhs =params(21)*y(13)+0.01*params(25)*x(it_, 5);
residual(40)= lhs-rhs;
lhs =y(20);
rhs =100*log(y(25)/y(1))+params(43);
residual(41)= lhs-rhs;
lhs =y(19);
rhs =100*log(y(32))+params(44);
residual(42)= lhs-rhs;
lhs =y(18);
rhs =400*(y(33)-1/params(7))+params(45);
residual(43)= lhs-rhs;
lhs =y(21);
rhs =100*log(y(30)/y(2))+params(46);
residual(44)= lhs-rhs;
lhs =y(17);
rhs =y(27)*(y(30)-y(42));
residual(45)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(45, 72);

  %
  % Jacobian matrix
  %

T517 = (-(T157*getPowerDeriv(y(27)+y(23),1-params(5)-params(6),1)));
T519 = (-(y(34)*y(24)*(1-params(5)-params(6))*y(51)))/((y(27)+y(23))*(y(27)+y(23)));
T659 = getPowerDeriv(T121,1-params(9),1);
T663 = getPowerDeriv(T121,(-params(9)),1);
T669 = getPowerDeriv(y(28),params(9)-1,1);
T690 = getPowerDeriv(y(29),(-params(9)),1);
T746 = getPowerDeriv(y(32),params(9)-1,1);
T757 = getPowerDeriv(y(32),params(9)-2,1);
T860 = (-(T420*getPowerDeriv(y(41)+y(40),1-params(5)-params(6),1)));
  g1(1,14)=1;
  g1(1,59)=(-params(7));
  g1(1,25)=(-(1/y(25)));
  g1(1,26)=getPowerDeriv(y(26),1+params(11),1)/(1+params(11));
  g1(2,15)=1;
  g1(2,60)=(-params(7));
  g1(2,27)=(-((y(30)-y(42))/(y(27)*(y(30)-y(42)))));
  g1(2,30)=(-(y(27)/(y(27)*(y(30)-y(42)))));
  g1(2,42)=(-((-y(27))/(y(27)*(y(30)-y(42)))));
  g1(3,16)=1;
  g1(3,30)=(-(1/y(42)));
  g1(3,42)=(-((-y(30))/(y(42)*y(42))));
  g1(4,22)=1;
  g1(4,23)=(-((-y(27))/((y(27)+y(23))*(y(27)+y(23)))));
  g1(4,27)=(-((y(27)+y(23)-y(27))/((y(27)+y(23))*(y(27)+y(23)))));
  g1(5,23)=1;
  g1(5,30)=(-(params(40)*exp(y(56))*params(4)*exp(y(55))));
  g1(5,55)=(-(params(40)*exp(y(56))*params(4)*y(30)*exp(y(55))));
  g1(5,56)=(-(params(4)*(y(30)*exp(y(55))-params(3))*exp(y(56))*params(40)));
  g1(6,23)=y(30);
  g1(6,24)=(-1);
  g1(6,25)=1;
  g1(6,27)=y(30);
  g1(6,30)=y(27)+y(23);
  g1(7,25)=(-T71);
  g1(7,26)=(-(y(25)*getPowerDeriv(y(26),params(11),1)));
  g1(7,31)=1;
  g1(8,25)=(-(params(7)*y(33)*exp(y(67))/y(61)/exp(y(58))/y(64)));
  g1(8,61)=(-((-(y(25)*params(7)*y(33)*exp(y(67))))/(y(61)*y(61))/exp(y(58))/y(64)));
  g1(8,64)=(-((-T84)/(y(64)*y(64))));
  g1(8,33)=(-(y(25)*params(7)*exp(y(67))/y(61)/exp(y(58))/y(64)));
  g1(8,58)=(-((-(y(25)*params(7)*y(33)*exp(y(67))/y(61)*exp(y(58))))/(exp(y(58))*exp(y(58)))/y(64)));
  g1(8,67)=(-(T84/y(64)));
  g1(9,24)=(-(exp(y(58))/y(25)));
  g1(9,25)=(-((-(y(24)*exp(y(58))))/(y(25)*y(25))));
  g1(9,28)=1;
  g1(9,62)=(-T98);
  g1(9,64)=(-(y(62)*params(7)*params(8)*params(18)*getPowerDeriv(y(64),params(9)-1,1)));
  g1(9,58)=(-(y(24)*exp(y(58))/y(25)));
  g1(10,24)=(-(exp(y(58))*params(10)*y(35)/y(25)));
  g1(10,25)=(-((-(y(24)*exp(y(58))*params(10)*y(35)))/(y(25)*y(25))));
  g1(10,29)=1;
  g1(10,63)=(-T111);
  g1(10,64)=(-(y(63)*params(7)*params(8)*getPowerDeriv(y(64),params(9),1)));
  g1(10,35)=(-(y(24)*exp(y(58))*params(10)/y(25)));
  g1(10,58)=(-(y(24)*exp(y(58))*params(10)*y(35)/y(25)));
  g1(11,28)=(-((1-params(8))*(-y(29))/(y(28)*y(28))*T659));
  g1(11,29)=(-((1-params(8))*T659*1/y(28)));
  g1(11,32)=(-(params(8)*1/params(18)*getPowerDeriv(T117,params(9)-1,1)));
  g1(12,28)=(-((1-params(8))*(-y(29))/(y(28)*y(28))*T663));
  g1(12,29)=(-((1-params(8))*T663*1/y(28)));
  g1(12,32)=(-(y(4)*params(8)*1/params(18)*getPowerDeriv(T117,params(9),1)));
  g1(12,4)=(-T129);
  g1(12,34)=1;
  g1(13,23)=y(30);
  g1(13,24)=(-(y(34)*y(35)*(1-params(5)-params(6))));
  g1(13,27)=y(30);
  g1(13,30)=y(27)+y(23);
  g1(13,34)=(-(y(24)*y(35)*(1-params(5)-params(6))));
  g1(13,35)=(-(y(34)*y(24)*(1-params(5)-params(6))));
  g1(14,24)=(-(y(34)*y(35)*params(5)));
  g1(14,26)=y(31);
  g1(14,31)=y(26);
  g1(14,34)=(-(y(24)*y(35)*params(5)));
  g1(14,35)=(-(y(34)*y(24)*params(5)));
  g1(15,23)=T517;
  g1(15,24)=y(34);
  g1(15,26)=(-(T158*T156*exp(y(54))*getPowerDeriv(y(26),params(5),1)));
  g1(15,27)=T517;
  g1(15,34)=y(24);
  g1(15,54)=(-(T157*T158));
  g1(16,1)=phi_y__;
  g1(16,25)=(-(phi_y__+phi_yg__*1/y(38)));
  g1(16,2)=phi_oc__;
  g1(16,30)=(-(phi_o__+phi_oc__));
  g1(16,32)=(-phi_p__);
  g1(16,3)=(-(params(16)*params(15)));
  g1(16,33)=params(15);
  g1(16,5)=(-phi_y__);
  g1(16,38)=(-((-phi_y__)+phi_yg__*(-y(25))/(y(38)*y(38))));
  g1(16,57)=(-1);
  g1(17,23)=(-T519);
  g1(17,24)=(-(y(34)*(1-params(5)-params(6))*y(51)/(y(27)+y(23))));
  g1(17,27)=(-(T519+(-1)/(y(27)*y(27))));
  g1(17,30)=(-((-y(43))-y(49)));
  g1(17,34)=(-(y(24)*(1-params(5)-params(6))*y(51)/(y(27)+y(23))));
  g1(17,43)=y(30);
  g1(17,49)=y(30);
  g1(17,51)=(-(y(34)*y(24)*(1-params(5)-params(6))/(y(27)+y(23))));
  g1(18,24)=(-((-y(45))-y(35)*params(10)*y(46)));
  g1(18,1)=y(3)*y(6)/y(25)/y(32);
  g1(18,25)=(-(phi_y__*(y(53)-params(7)*y(66))+(-y(43))-(-(y(1)*y(3)*y(6)))/(y(25)*y(25))/y(32)+phi_yg__*y(53)/y(38)));
  g1(18,31)=(-y(52));
  g1(18,32)=(-(y(1)*y(3)*y(6)/y(25)))/(y(32)*y(32));
  g1(18,3)=y(1)*y(6)/y(25)/y(32);
  g1(18,35)=y(24)*params(10)*y(46);
  g1(18,38)=(-((-(y(25)*phi_yg__*y(53)))/(y(38)*y(38))));
  g1(18,43)=y(25);
  g1(18,6)=y(3)*y(1)/y(25)/y(32);
  g1(18,44)=(-1);
  g1(18,45)=y(24);
  g1(18,46)=y(24)*params(10)*y(35);
  g1(18,52)=(-y(31));
  g1(18,53)=(-(y(25)*phi_y__+y(25)*phi_yg__/y(38)));
  g1(18,66)=(-(y(25)*phi_y__*(-params(7))));
  g1(19,34)=(-(y(35)*(1-params(5)-params(6))*y(49)-y(35)*params(5)*y(50)-y(51)));
  g1(19,35)=(-(exp(y(58))*params(10)*y(46)+y(34)*(1-params(5)-params(6))*y(49)-y(34)*params(5)*y(50)));
  g1(19,43)=(-1);
  g1(19,45)=(-exp(y(58)));
  g1(19,46)=(-(exp(y(58))*params(10)*y(35)));
  g1(19,49)=(-(y(34)*y(35)*(1-params(5)-params(6))));
  g1(19,50)=y(34)*y(35)*params(5);
  g1(19,51)=y(34);
  g1(19,58)=(-(exp(y(58))*y(45)+exp(y(58))*y(35)*params(10)*y(46)));
  g1(20,1)=(-(params(18)*params(8)*y(7)*T268));
  g1(20,25)=y(45);
  g1(20,28)=(-(T276*getPowerDeriv(y(28),params(9)-2,1)+params(9)*(1-params(8))*y(48)*T284*T669));
  g1(20,29)=(-(T278*(params(9)-1)*(1-params(8))*y(47)*getPowerDeriv(y(29),1-params(9),1)+T286*params(9)*(1-params(8))*y(48)*T690));
  g1(20,32)=(-(y(1)*params(18)*params(8)*y(7)*T746));
  g1(20,7)=(-(T268*y(1)*params(8)*params(18)));
  g1(20,45)=y(25);
  g1(20,47)=(-(T278*T275*(params(9)-1)*(1-params(8))));
  g1(20,48)=(-(T286*T284*params(9)*(1-params(8))));
  g1(21,1)=(-(params(8)*y(8)*T293));
  g1(21,25)=y(46);
  g1(21,28)=(-(T284*(1-params(9))*(1-params(8))*y(47)*T669-T303*getPowerDeriv(y(28),params(9),1)));
  g1(21,29)=(-(T286*(1-params(9))*(1-params(8))*y(47)*T690-T304*params(9)*(1-params(8))*y(48)*getPowerDeriv(y(29),(-params(9))-1,1)));
  g1(21,32)=(-(y(1)*params(8)*y(8)*getPowerDeriv(y(32),params(9),1)));
  g1(21,8)=(-(T293*params(8)*y(1)));
  g1(21,46)=y(25);
  g1(21,47)=(-(T286*T284*(1-params(8))*(1-params(9))));
  g1(21,48)=T304*T302*params(9)*(1-params(8));
  g1(22,24)=(-(y(34)*params(5)*y(51)/y(26)));
  g1(22,25)=(-(T317*params(11)*y(52)));
  g1(22,26)=(-((-(y(34)*y(24)*params(5)*y(51)))/(y(26)*y(26))+params(11)*y(25)*y(52)*getPowerDeriv(y(26),params(11)-1,1)));
  g1(22,31)=(-y(50));
  g1(22,34)=(-(y(24)*params(5)*y(51)/y(26)));
  g1(22,50)=(-y(31));
  g1(22,51)=(-(y(34)*y(24)*params(5)/y(26)));
  g1(22,52)=(-(T317*y(25)*params(11)));
  g1(23,23)=(-((-(2*(y(43)+y(49))))+params(4)*params(40)*exp(y(56))*exp(y(55))*T519));
  g1(23,24)=(-(params(4)*params(40)*exp(y(56))*exp(y(55))*y(34)*(1-params(5)-params(6))*y(51)/(y(27)+y(23))));
  g1(23,27)=(-(params(4)*params(40)*exp(y(56))*exp(y(55))*T519+(-(y(43)+y(49)))));
  g1(23,30)=(-((-1)/(T322*T322)));
  g1(23,34)=(-(params(4)*params(40)*exp(y(56))*exp(y(55))*y(24)*(1-params(5)-params(6))*y(51)/(y(27)+y(23))));
  g1(23,43)=y(27)+2*y(23);
  g1(23,49)=y(27)+2*y(23);
  g1(23,51)=(-(params(4)*params(40)*exp(y(56))*exp(y(55))*y(34)*y(24)*(1-params(5)-params(6))/(y(27)+y(23))));
  g1(23,53)=(-(phi_o__+phi_oc__));
  g1(23,66)=(-(phi_oc__*(-params(7))));
  g1(23,55)=(-(T332+(-exp(y(55)))/(exp(y(55))*exp(y(55)))/(T322*T322)));
  g1(23,56)=(-T332);
  g1(24,1)=(-(y(3)*(-y(6))/y(25)/T343+y(28)*(params(9)-1)*params(18)*params(8)*y(7)*T347+y(29)*T268*params(9)*params(8)*y(8)));
  g1(24,25)=(-((-(y(1)*y(3)*(-y(6))))/(y(25)*y(25))/T343));
  g1(24,28)=(-(y(1)*(params(9)-1)*params(18)*params(8)*y(7)*T347));
  g1(24,29)=(-(T268*y(1)*params(9)*params(8)*y(8)));
  g1(24,32)=(-((-(y(1)*y(3)*(-y(6))/y(25)*2*y(32)))/(T343*T343)+y(28)*y(1)*(params(9)-1)*params(18)*params(8)*y(7)*T757+y(29)*y(1)*params(9)*params(8)*y(8)*T746+T359*(params(9)-1)*params(8)*y(47)*T757+y(4)*T365*T746));
  g1(24,3)=(-(y(1)*(-y(6))/y(25)/T343));
  g1(24,4)=(-(T268*T365));
  g1(24,6)=(-(y(1)*(-y(3))/y(25)/T343));
  g1(24,7)=(-(y(28)*T347*y(1)*(params(9)-1)*params(8)*params(18)));
  g1(24,8)=(-(y(29)*T268*y(1)*params(8)*params(9)));
  g1(24,47)=(-(T359*T347*params(8)*(params(9)-1)));
  g1(24,48)=(-(y(4)*T268*T364*params(8)*params(9)));
  g1(24,53)=(-phi_p__);
  g1(25,24)=(-(y(35)*(1-params(5)-params(6))*y(49)-y(35)*params(5)*y(50)-y(51)));
  g1(25,64)=(-(params(8)*params(7)*y(65)*1/params(18)*getPowerDeriv(y(64)/params(18),params(9),1)));
  g1(25,35)=(-(y(24)*(1-params(5)-params(6))*y(49)-y(24)*params(5)*y(50)));
  g1(25,48)=1;
  g1(25,65)=(-(params(7)*params(8)*T376));
  g1(25,49)=(-(y(24)*y(35)*(1-params(5)-params(6))));
  g1(25,50)=y(24)*y(35)*params(5);
  g1(25,51)=y(24);
  g1(26,34)=(-((1-params(5)-params(6))*y(49)-params(5)*y(50)));
  g1(26,46)=(-(exp(y(58))*params(10)));
  g1(26,49)=(-(y(34)*(1-params(5)-params(6))));
  g1(26,50)=y(34)*params(5);
  g1(26,58)=(-(exp(y(58))*params(10)*y(46)));
  g1(27,33)=(-((-y(44))/(y(33)*y(33))));
  g1(27,44)=(-(1/y(33)));
  g1(27,53)=params(15);
  g1(27,66)=params(15)*(-(params(16)*params(7)));
  g1(28,26)=(-y(50));
  g1(28,50)=(-y(26));
  g1(28,52)=1;
  g1(29,41)=1;
  g1(29,42)=(-(params(40)*exp(y(56))*params(4)*exp(y(55))));
  g1(29,55)=(-(params(40)*exp(y(56))*params(4)*y(42)*exp(y(55))));
  g1(29,56)=(-(params(40)*exp(y(56))*params(4)*(y(42)*exp(y(55))-params(3))));
  g1(30,37)=(-((1-params(5)-params(6))/params(10)));
  g1(30,40)=y(42);
  g1(30,41)=y(42);
  g1(30,42)=y(41)+y(40);
  g1(31,42)=1;
  g1(31,55)=(-((-exp(y(55)))/(exp(y(55))*exp(y(55)))));
  g1(32,37)=1;
  g1(32,40)=T860;
  g1(32,41)=T860;
  g1(32,54)=(-T422);
  g1(33,37)=(-(1-(1-params(5)-params(6))/params(10)));
  g1(33,38)=1;
  g1(34,24)=(-(1/y(37)));
  g1(34,36)=1;
  g1(34,37)=(-((-y(24))/(y(37)*y(37))));
  g1(35,25)=(-(1/y(38)));
  g1(35,38)=(-((-y(25))/(y(38)*y(38))));
  g1(35,39)=1;
  g1(36,9)=(-params(19));
  g1(36,54)=1;
  g1(36,68)=(-(0.01*params(24)));
  g1(37,10)=(-params(20));
  g1(37,55)=1;
  g1(37,69)=0.01*params(26);
  g1(38,11)=(-params(22));
  g1(38,56)=1;
  g1(38,70)=0.01*params(27);
  g1(39,12)=(-params(23));
  g1(39,57)=1;
  g1(39,71)=0.01*params(28);
  g1(40,13)=(-params(21));
  g1(40,58)=1;
  g1(40,72)=(-(0.01*params(25)));
  g1(41,20)=1;
  g1(41,1)=(-(100*(-y(25))/(y(1)*y(1))/(y(25)/y(1))));
  g1(41,25)=(-(100*1/y(1)/(y(25)/y(1))));
  g1(42,19)=1;
  g1(42,32)=(-(100*1/y(32)));
  g1(43,18)=1;
  g1(43,33)=(-400);
  g1(44,21)=1;
  g1(44,2)=(-(100*(-y(30))/(y(2)*y(2))/(y(30)/y(2))));
  g1(44,30)=(-(100*1/y(2)/(y(30)/y(2))));
  g1(45,17)=1;
  g1(45,27)=(-(y(30)-y(42)));
  g1(45,30)=(-y(27));
  g1(45,42)=y(27);

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],45,5184);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],45,373248);
end
end
end
end
