function [residual, g1, g2, g3] = NPmodel_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 45, 1);

%
% Model equations
%

phi_p__ = params(12)*(1-params(16));
phi_y__ = (1-params(16))*params(14);
phi_yg__ = (1-params(16))*params(41);
phi_o__ = (1-params(16))*params(13);
phi_oc__ = (1-params(16))*params(42);
T69 = y(13)^params(11);
T79 = y(12)*params(7)*y(20)*exp(y(45))/y(12)/exp(y(45));
T92 = y(19)^(params(9)-1);
T104 = y(19)^params(9);
T109 = y(19)/params(18);
T113 = y(16)/y(15);
T120 = T109^params(9);
T147 = params(35)^params(6);
T148 = exp(y(41))*y(13)^params(5)*T147;
T149 = (y(14)+y(10))^(1-params(5)-params(6));
T249 = y(16)^(1-params(9));
T250 = (params(9)-1)*(1-params(8))*y(34)*T249;
T252 = y(15)^(params(9)-2);
T258 = y(16)^(-params(9));
T260 = y(15)^(params(9)-1);
T274 = y(16)^((-params(9))-1);
T275 = params(9)*(1-params(8))*y(35)*T274;
T276 = y(15)^params(9);
T289 = y(13)^(params(11)-1);
T294 = y(17)-1/exp(y(42));
T304 = params(4)*params(40)*exp(y(43))*exp(y(42))*y(21)*y(11)*(1-params(5)-params(6))*y(38)/(y(14)+y(10));
T315 = y(19)^2;
T319 = y(19)^(params(9)-2);
T331 = params(18)^(1-params(9));
T336 = params(18)^(-params(9));
T337 = params(9)*params(8)*y(35)*T336;
T389 = T147*exp(y(41))*params(36)^params(5);
T391 = T389*(y(28)+y(27))^(1-params(5)-params(6));
lhs =y(1);
rhs =log(y(12))-y(13)^(1+params(11))/(1+params(11))+y(1)*params(7);
residual(1)= lhs-rhs;
lhs =y(2);
rhs =log(y(14)*(y(17)-y(29)))+params(7)*y(2);
residual(2)= lhs-rhs;
lhs =y(3);
rhs =y(17)/y(29);
residual(3)= lhs-rhs;
lhs =y(9);
rhs =y(14)/(y(14)+y(10));
residual(4)= lhs-rhs;
lhs =y(10);
rhs =params(4)*(y(17)*exp(y(42))-params(3))*exp(y(43))*params(40);
residual(5)= lhs-rhs;
lhs =y(12);
rhs =y(11)-y(17)*(y(14)+y(10));
residual(6)= lhs-rhs;
lhs =y(18);
rhs =y(12)*T69;
residual(7)= lhs-rhs;
lhs =1;
rhs =T79/y(19);
residual(8)= lhs-rhs;
lhs =y(15);
rhs =y(11)*exp(y(45))/y(12)+y(15)*params(7)*params(8)*params(18)*T92;
residual(9)= lhs-rhs;
lhs =y(16);
rhs =y(11)*exp(y(45))*params(10)*y(22)/y(12)+y(16)*params(7)*params(8)*T104;
residual(10)= lhs-rhs;
lhs =1;
rhs =params(8)*T109^(params(9)-1)+(1-params(8))*T113^(1-params(9));
residual(11)= lhs-rhs;
lhs =y(21);
rhs =y(21)*params(8)*T120+(1-params(8))*T113^(-params(9));
residual(12)= lhs-rhs;
lhs =y(17)*(y(14)+y(10));
rhs =y(21)*y(11)*y(22)*(1-params(5)-params(6));
residual(13)= lhs-rhs;
lhs =y(13)*y(18);
rhs =y(21)*y(11)*y(22)*params(5);
residual(14)= lhs-rhs;
lhs =y(11)*y(21);
rhs =T148*T149;
residual(15)= lhs-rhs;
lhs =params(15)*(y(20)-params(17));
rhs =params(16)*params(15)*(y(20)-params(17))+(y(19)-1)*phi_p__+(y(12)/y(25)-params(31))*phi_yg__+(y(17)-params(29))*phi_o__+y(44);
residual(16)= lhs-rhs;
lhs =0;
rhs =1/y(14)-y(17)*y(30)-y(17)*y(36)+y(21)*y(11)*(1-params(5)-params(6))*y(38)/(y(14)+y(10));
residual(17)= lhs-rhs;
lhs =0;
rhs =y(12)*(-y(30))+y(31)-y(12)*y(20)*y(31)/y(12)/y(19)-y(11)*y(32)-y(11)*y(22)*params(10)*y(33)+y(18)*y(39)+y(12)*phi_y__*(y(40)-params(7)*y(40))+y(12)*phi_yg__*y(40)/y(25);
residual(18)= lhs-rhs;
lhs =0;
rhs =y(30)+exp(y(45))*y(32)+exp(y(45))*y(22)*params(10)*y(33)+y(21)*y(22)*(1-params(5)-params(6))*y(36)-y(21)*y(22)*params(5)*y(37)-y(21)*y(38);
residual(19)= lhs-rhs;
lhs =0;
rhs =T92*y(12)*params(18)*params(8)*y(32)-y(12)*y(32)+T250*T252+params(9)*(1-params(8))*y(35)*T258*T260;
residual(20)= lhs-rhs;
lhs =0;
rhs =T104*y(12)*params(8)*y(33)-y(12)*y(33)+T260*T258*(1-params(9))*(1-params(8))*y(34)-T275*T276;
residual(21)= lhs-rhs;
lhs =0;
rhs =y(18)*y(37)+y(21)*y(11)*params(5)*y(38)/y(13)+params(11)*y(12)*y(39)*T289;
residual(22)= lhs-rhs;
lhs =0;
rhs =1/T294-(y(14)+2*y(10))*(y(30)+y(36))+T304+phi_o__*y(40)+phi_oc__*(y(40)-params(7)*y(40));
residual(23)= lhs-rhs;
lhs =0;
rhs =y(12)*y(20)*(-y(31))/y(12)/T315+y(15)*y(12)*(params(9)-1)*params(18)*params(8)*y(32)*T319+y(16)*T92*y(12)*params(9)*params(8)*y(33)+T319*(params(9)-1)*params(8)*y(34)*T331+y(21)*T92*T337+phi_p__*y(40);
residual(24)= lhs-rhs;
lhs =0;
rhs =T120*params(8)*params(7)*y(35)-y(35)+y(11)*y(22)*(1-params(5)-params(6))*y(36)-y(11)*y(22)*params(5)*y(37)-y(11)*y(38);
residual(25)= lhs-rhs;
lhs =0;
rhs =exp(y(45))*params(10)*y(33)+y(21)*(1-params(5)-params(6))*y(36)-y(21)*params(5)*y(37);
residual(26)= lhs-rhs;
lhs =0;
rhs =y(31)/y(20)-params(15)*(y(40)-y(40)*params(16)*params(7));
residual(27)= lhs-rhs;
lhs =0;
rhs =y(13)*y(37)-y(39);
residual(28)= lhs-rhs;
lhs =y(28);
rhs =params(40)*exp(y(43))*params(4)*(y(29)*exp(y(42))-params(3));
residual(29)= lhs-rhs;
lhs =y(29)*(y(28)+y(27));
rhs =(1-params(5)-params(6))/params(10)*y(24);
residual(30)= lhs-rhs;
lhs =y(29);
rhs =1/exp(y(42));
residual(31)= lhs-rhs;
lhs =y(24);
rhs =T391;
residual(32)= lhs-rhs;
lhs =y(25);
rhs =y(24)*(1-(1-params(5)-params(6))/params(10));
residual(33)= lhs-rhs;
lhs =y(23);
rhs =y(11)/y(24);
residual(34)= lhs-rhs;
lhs =y(26);
rhs =y(12)/y(25);
residual(35)= lhs-rhs;
lhs =y(41);
rhs =y(41)*params(19)+0.01*params(24)*x(1);
residual(36)= lhs-rhs;
lhs =y(42);
rhs =y(42)*params(20)-0.01*params(26)*x(2);
residual(37)= lhs-rhs;
lhs =y(43);
rhs =y(43)*params(22)-0.01*params(27)*x(3);
residual(38)= lhs-rhs;
lhs =y(44);
rhs =y(44)*params(23)-0.01*params(28)*x(4);
residual(39)= lhs-rhs;
lhs =y(45);
rhs =y(45)*params(21)+0.01*params(25)*x(5);
residual(40)= lhs-rhs;
lhs =y(7);
rhs =params(43);
residual(41)= lhs-rhs;
lhs =y(6);
rhs =100*log(y(19))+params(44);
residual(42)= lhs-rhs;
lhs =y(5);
rhs =400*(y(20)-1/params(7))+params(45);
residual(43)= lhs-rhs;
lhs =y(8);
rhs =params(46);
residual(44)= lhs-rhs;
lhs =y(4);
rhs =y(14)*(y(17)-y(29));
residual(45)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(45, 45);

  %
  % Jacobian matrix
  %

T473 = (-(T148*getPowerDeriv(y(14)+y(10),1-params(5)-params(6),1)));
T475 = (-(y(21)*y(11)*(1-params(5)-params(6))*y(38)))/((y(14)+y(10))*(y(14)+y(10)));
T581 = getPowerDeriv(T113,1-params(9),1);
T585 = getPowerDeriv(T113,(-params(9)),1);
T591 = getPowerDeriv(y(15),params(9)-1,1);
T612 = getPowerDeriv(y(16),(-params(9)),1);
T645 = getPowerDeriv(y(19),params(9)-1,1);
T649 = getPowerDeriv(y(19),params(9),1);
T659 = 1/params(18)*getPowerDeriv(T109,params(9),1);
T676 = getPowerDeriv(y(19),params(9)-2,1);
T764 = (-(T389*getPowerDeriv(y(28)+y(27),1-params(5)-params(6),1)));
  g1(1,1)=1-params(7);
  g1(1,12)=(-(1/y(12)));
  g1(1,13)=getPowerDeriv(y(13),1+params(11),1)/(1+params(11));
  g1(2,2)=1-params(7);
  g1(2,14)=(-((y(17)-y(29))/(y(14)*(y(17)-y(29)))));
  g1(2,17)=(-(y(14)/(y(14)*(y(17)-y(29)))));
  g1(2,29)=(-((-y(14))/(y(14)*(y(17)-y(29)))));
  g1(3,3)=1;
  g1(3,17)=(-(1/y(29)));
  g1(3,29)=(-((-y(17))/(y(29)*y(29))));
  g1(4,9)=1;
  g1(4,10)=(-((-y(14))/((y(14)+y(10))*(y(14)+y(10)))));
  g1(4,14)=(-((y(14)+y(10)-y(14))/((y(14)+y(10))*(y(14)+y(10)))));
  g1(5,10)=1;
  g1(5,17)=(-(params(40)*exp(y(43))*params(4)*exp(y(42))));
  g1(5,42)=(-(params(40)*exp(y(43))*params(4)*y(17)*exp(y(42))));
  g1(5,43)=(-(params(4)*(y(17)*exp(y(42))-params(3))*exp(y(43))*params(40)));
  g1(6,10)=y(17);
  g1(6,11)=(-1);
  g1(6,12)=1;
  g1(6,14)=y(17);
  g1(6,17)=y(14)+y(10);
  g1(7,12)=(-T69);
  g1(7,13)=(-(y(12)*getPowerDeriv(y(13),params(11),1)));
  g1(7,18)=1;
  g1(8,19)=(-((-T79)/(y(19)*y(19))));
  g1(8,20)=(-(y(12)*params(7)*exp(y(45))/y(12)/exp(y(45))/y(19)));
  g1(9,11)=(-(exp(y(45))/y(12)));
  g1(9,12)=(-((-(y(11)*exp(y(45))))/(y(12)*y(12))));
  g1(9,15)=1-params(7)*params(8)*params(18)*T92;
  g1(9,19)=(-(y(15)*params(7)*params(8)*params(18)*T645));
  g1(9,45)=(-(y(11)*exp(y(45))/y(12)));
  g1(10,11)=(-(exp(y(45))*params(10)*y(22)/y(12)));
  g1(10,12)=(-((-(y(11)*exp(y(45))*params(10)*y(22)))/(y(12)*y(12))));
  g1(10,16)=1-params(7)*params(8)*T104;
  g1(10,19)=(-(y(16)*params(7)*params(8)*T649));
  g1(10,22)=(-(y(11)*exp(y(45))*params(10)/y(12)));
  g1(10,45)=(-(y(11)*exp(y(45))*params(10)*y(22)/y(12)));
  g1(11,15)=(-((1-params(8))*(-y(16))/(y(15)*y(15))*T581));
  g1(11,16)=(-((1-params(8))*T581*1/y(15)));
  g1(11,19)=(-(params(8)*1/params(18)*getPowerDeriv(T109,params(9)-1,1)));
  g1(12,15)=(-((1-params(8))*(-y(16))/(y(15)*y(15))*T585));
  g1(12,16)=(-((1-params(8))*T585*1/y(15)));
  g1(12,19)=(-(y(21)*params(8)*T659));
  g1(12,21)=1-params(8)*T120;
  g1(13,10)=y(17);
  g1(13,11)=(-(y(21)*y(22)*(1-params(5)-params(6))));
  g1(13,14)=y(17);
  g1(13,17)=y(14)+y(10);
  g1(13,21)=(-(y(11)*y(22)*(1-params(5)-params(6))));
  g1(13,22)=(-(y(21)*y(11)*(1-params(5)-params(6))));
  g1(14,11)=(-(y(21)*y(22)*params(5)));
  g1(14,13)=y(18);
  g1(14,18)=y(13);
  g1(14,21)=(-(y(11)*y(22)*params(5)));
  g1(14,22)=(-(y(21)*y(11)*params(5)));
  g1(15,10)=T473;
  g1(15,11)=y(21);
  g1(15,13)=(-(T149*T147*exp(y(41))*getPowerDeriv(y(13),params(5),1)));
  g1(15,14)=T473;
  g1(15,21)=y(11);
  g1(15,41)=(-(T148*T149));
  g1(16,12)=(-(phi_yg__*1/y(25)));
  g1(16,17)=(-phi_o__);
  g1(16,19)=(-phi_p__);
  g1(16,20)=params(15)-params(16)*params(15);
  g1(16,25)=(-(phi_yg__*(-y(12))/(y(25)*y(25))));
  g1(16,44)=(-1);
  g1(17,10)=(-T475);
  g1(17,11)=(-(y(21)*(1-params(5)-params(6))*y(38)/(y(14)+y(10))));
  g1(17,14)=(-(T475+(-1)/(y(14)*y(14))));
  g1(17,17)=(-((-y(30))-y(36)));
  g1(17,21)=(-(y(11)*(1-params(5)-params(6))*y(38)/(y(14)+y(10))));
  g1(17,30)=y(17);
  g1(17,36)=y(17);
  g1(17,38)=(-(y(21)*y(11)*(1-params(5)-params(6))/(y(14)+y(10))));
  g1(18,11)=(-((-y(32))-y(22)*params(10)*y(33)));
  g1(18,12)=(-((-y(30))+phi_y__*(y(40)-params(7)*y(40))+phi_yg__*y(40)/y(25)));
  g1(18,18)=(-y(39));
  g1(18,19)=(-(y(12)*y(20)*y(31)/y(12)))/(y(19)*y(19));
  g1(18,20)=y(12)*y(31)/y(12)/y(19);
  g1(18,22)=y(11)*params(10)*y(33);
  g1(18,25)=(-((-(y(12)*phi_yg__*y(40)))/(y(25)*y(25))));
  g1(18,30)=y(12);
  g1(18,31)=(-(1-y(12)*y(20)/y(12)/y(19)));
  g1(18,32)=y(11);
  g1(18,33)=y(11)*params(10)*y(22);
  g1(18,39)=(-y(18));
  g1(18,40)=(-(y(12)*phi_y__*(1-params(7))+y(12)*phi_yg__/y(25)));
  g1(19,21)=(-(y(22)*(1-params(5)-params(6))*y(36)-y(22)*params(5)*y(37)-y(38)));
  g1(19,22)=(-(exp(y(45))*params(10)*y(33)+y(21)*(1-params(5)-params(6))*y(36)-y(21)*params(5)*y(37)));
  g1(19,30)=(-1);
  g1(19,32)=(-exp(y(45)));
  g1(19,33)=(-(exp(y(45))*params(10)*y(22)));
  g1(19,36)=(-(y(21)*y(22)*(1-params(5)-params(6))));
  g1(19,37)=y(21)*y(22)*params(5);
  g1(19,38)=y(21);
  g1(19,45)=(-(exp(y(45))*y(32)+exp(y(45))*y(22)*params(10)*y(33)));
  g1(20,12)=(-(T92*params(18)*params(8)*y(32)-y(32)));
  g1(20,15)=(-(T250*getPowerDeriv(y(15),params(9)-2,1)+params(9)*(1-params(8))*y(35)*T258*T591));
  g1(20,16)=(-(T252*(params(9)-1)*(1-params(8))*y(34)*getPowerDeriv(y(16),1-params(9),1)+T260*params(9)*(1-params(8))*y(35)*T612));
  g1(20,19)=(-(y(12)*params(18)*params(8)*y(32)*T645));
  g1(20,32)=(-(T92*y(12)*params(8)*params(18)-y(12)));
  g1(20,34)=(-(T252*T249*(params(9)-1)*(1-params(8))));
  g1(20,35)=(-(T260*T258*params(9)*(1-params(8))));
  g1(21,12)=(-(T104*params(8)*y(33)-y(33)));
  g1(21,15)=(-(T258*(1-params(9))*(1-params(8))*y(34)*T591-T275*getPowerDeriv(y(15),params(9),1)));
  g1(21,16)=(-(T260*(1-params(9))*(1-params(8))*y(34)*T612-T276*params(9)*(1-params(8))*y(35)*getPowerDeriv(y(16),(-params(9))-1,1)));
  g1(21,19)=(-(y(12)*params(8)*y(33)*T649));
  g1(21,33)=(-(T104*y(12)*params(8)-y(12)));
  g1(21,34)=(-(T260*T258*(1-params(8))*(1-params(9))));
  g1(21,35)=T276*T274*params(9)*(1-params(8));
  g1(22,11)=(-(y(21)*params(5)*y(38)/y(13)));
  g1(22,12)=(-(T289*params(11)*y(39)));
  g1(22,13)=(-((-(y(21)*y(11)*params(5)*y(38)))/(y(13)*y(13))+params(11)*y(12)*y(39)*getPowerDeriv(y(13),params(11)-1,1)));
  g1(22,18)=(-y(37));
  g1(22,21)=(-(y(11)*params(5)*y(38)/y(13)));
  g1(22,37)=(-y(18));
  g1(22,38)=(-(y(21)*y(11)*params(5)/y(13)));
  g1(22,39)=(-(T289*y(12)*params(11)));
  g1(23,10)=(-((-(2*(y(30)+y(36))))+params(4)*params(40)*exp(y(43))*exp(y(42))*T475));
  g1(23,11)=(-(params(4)*params(40)*exp(y(43))*exp(y(42))*y(21)*(1-params(5)-params(6))*y(38)/(y(14)+y(10))));
  g1(23,14)=(-(params(4)*params(40)*exp(y(43))*exp(y(42))*T475+(-(y(30)+y(36)))));
  g1(23,17)=(-((-1)/(T294*T294)));
  g1(23,21)=(-(params(4)*params(40)*exp(y(43))*exp(y(42))*y(11)*(1-params(5)-params(6))*y(38)/(y(14)+y(10))));
  g1(23,30)=y(14)+2*y(10);
  g1(23,36)=y(14)+2*y(10);
  g1(23,38)=(-(params(4)*params(40)*exp(y(43))*exp(y(42))*y(21)*y(11)*(1-params(5)-params(6))/(y(14)+y(10))));
  g1(23,40)=(-(phi_o__+phi_oc__*(1-params(7))));
  g1(23,42)=(-(T304+(-exp(y(42)))/(exp(y(42))*exp(y(42)))/(T294*T294)));
  g1(23,43)=(-T304);
  g1(24,12)=(-(y(15)*(params(9)-1)*params(18)*params(8)*y(32)*T319+y(16)*T92*params(9)*params(8)*y(33)));
  g1(24,15)=(-(y(12)*(params(9)-1)*params(18)*params(8)*y(32)*T319));
  g1(24,16)=(-(T92*y(12)*params(9)*params(8)*y(33)));
  g1(24,19)=(-((-(y(12)*y(20)*(-y(31))/y(12)*2*y(19)))/(T315*T315)+y(15)*y(12)*(params(9)-1)*params(18)*params(8)*y(32)*T676+y(16)*y(12)*params(9)*params(8)*y(33)*T645+T331*(params(9)-1)*params(8)*y(34)*T676+y(21)*T337*T645));
  g1(24,20)=(-(y(12)*(-y(31))/y(12)/T315));
  g1(24,21)=(-(T92*T337));
  g1(24,31)=(-(y(12)*(-y(20))/y(12)/T315));
  g1(24,32)=(-(y(15)*T319*y(12)*(params(9)-1)*params(8)*params(18)));
  g1(24,33)=(-(y(16)*T92*y(12)*params(8)*params(9)));
  g1(24,34)=(-(T331*T319*params(8)*(params(9)-1)));
  g1(24,35)=(-(y(21)*T92*T336*params(8)*params(9)));
  g1(24,40)=(-phi_p__);
  g1(25,11)=(-(y(22)*(1-params(5)-params(6))*y(36)-y(22)*params(5)*y(37)-y(38)));
  g1(25,19)=(-(params(8)*params(7)*y(35)*T659));
  g1(25,22)=(-(y(11)*(1-params(5)-params(6))*y(36)-y(11)*params(5)*y(37)));
  g1(25,35)=(-(params(7)*params(8)*T120-1));
  g1(25,36)=(-(y(11)*y(22)*(1-params(5)-params(6))));
  g1(25,37)=y(11)*y(22)*params(5);
  g1(25,38)=y(11);
  g1(26,21)=(-((1-params(5)-params(6))*y(36)-params(5)*y(37)));
  g1(26,33)=(-(exp(y(45))*params(10)));
  g1(26,36)=(-(y(21)*(1-params(5)-params(6))));
  g1(26,37)=y(21)*params(5);
  g1(26,45)=(-(exp(y(45))*params(10)*y(33)));
  g1(27,20)=(-((-y(31))/(y(20)*y(20))));
  g1(27,31)=(-(1/y(20)));
  g1(27,40)=params(15)*(1-params(16)*params(7));
  g1(28,13)=(-y(37));
  g1(28,37)=(-y(13));
  g1(28,39)=1;
  g1(29,28)=1;
  g1(29,29)=(-(params(40)*exp(y(43))*params(4)*exp(y(42))));
  g1(29,42)=(-(params(40)*exp(y(43))*params(4)*y(29)*exp(y(42))));
  g1(29,43)=(-(params(40)*exp(y(43))*params(4)*(y(29)*exp(y(42))-params(3))));
  g1(30,24)=(-((1-params(5)-params(6))/params(10)));
  g1(30,27)=y(29);
  g1(30,28)=y(29);
  g1(30,29)=y(28)+y(27);
  g1(31,29)=1;
  g1(31,42)=(-((-exp(y(42)))/(exp(y(42))*exp(y(42)))));
  g1(32,24)=1;
  g1(32,27)=T764;
  g1(32,28)=T764;
  g1(32,41)=(-T391);
  g1(33,24)=(-(1-(1-params(5)-params(6))/params(10)));
  g1(33,25)=1;
  g1(34,11)=(-(1/y(24)));
  g1(34,23)=1;
  g1(34,24)=(-((-y(11))/(y(24)*y(24))));
  g1(35,12)=(-(1/y(25)));
  g1(35,25)=(-((-y(12))/(y(25)*y(25))));
  g1(35,26)=1;
  g1(36,41)=1-params(19);
  g1(37,42)=1-params(20);
  g1(38,43)=1-params(22);
  g1(39,44)=1-params(23);
  g1(40,45)=1-params(21);
  g1(41,7)=1;
  g1(42,6)=1;
  g1(42,19)=(-(100*1/y(19)));
  g1(43,5)=1;
  g1(43,20)=(-400);
  g1(44,8)=1;
  g1(45,4)=1;
  g1(45,14)=(-(y(17)-y(29)));
  g1(45,17)=(-y(14));
  g1(45,29)=y(14);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],45,2025);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],45,91125);
end
end
end
end
