
var V_IMP, 		// value function importer
	V_EXP, 		// value function OPEC
	pomu,       // markup on real oil prices (OPEC monopoly effect)
	profit,     // profits of OPEC
	R_obs       // observed interest rate
	p_obs,      // observed inflation
	y_obs,      // observed GDP 
	oil_obs,    // observed real price of oil
	SO,          // share of OPEC in oil prpoduction
	XX,          // oil production, fringe producers
	Y,           // GDP in US
	C,           // Consumption in US
	L,           // Labor, US
	O,           // oil production, OPEC
	D,           // Calvo pricing system, denominator, US
	N,           // Calvo pricing system, nominator, US
	po,          // real price of oil, monopoly
	w,           // real wage, US
	PI,          // inflation, US
	R,           // nominal interest rate, US
	DP,          // price dispersion (delta), US
	mc,          // marginal costs, US
    Ygap, 
	Ye,          // Output, US, perfect competition
	Ce,          // Consumption, US, perfect competition
	Cgap, 
	Oe,          // oil production, OPEC, perfect competition
	Xe,          // oil production, fringe producers, perfect competition
	poe,         // real price of oil, perfect competitioin
	L1, L2, L3, L4, L5, L6, L7, L8, L9, L10, L11, 
	a,          // AR(1), technology shocks
	zz,         // AR(1), oil sector productivity shock
	x,          // AR(1), number of oil producers shock 
	rr,         // AR(1), MP shock
	zb;         // AR(1), discount factor shock

varexo ea,      // technology shock
	   ez,      // oil sector productivity shock
	   ex,      // number of oil producers shock 
	   er,      // MP shock
	   ezb;     // preference shock

parameters A, Z, aa, bb, alpha, gamma, beta, theta, epsilon, mu, psi,
           phi_p_LR, phi_o_LR, phi_y_LR, phi_i, phi_R, R_bar, PI_bar, 
           rho_a, rho_z, rho_zb, rho_x, rho_r, stderrea, stderrezb, stderrez, stderrex, stderrer,
           po_ss, pomu_ss, Cgap_ss, Ygap_ss, SO_ss, X_O, K_ss, Lf_ss, Of_ss, Xf_ss, pof_ss, Omeg_fss, phi_yg_LR,
           phi_oc_LR, mu_y, mu_p, mu_R, mu_oil;

% steady-state
mu_y   = 0.5;
mu_p   = 0.5;
mu_R   = 4;
mu_oil = 0;


% Rule switch: 0-Targeting; 1-Taylor 
% Note: interest rate targeting is when phi_i=1 and all other phi's are zero
phi_i =	1;   

% Taylor rule reaction coefficients (when phi_i=1) / target weights (when phi_i=0)

phi_p_LR  =	1.5;    % long-run inflation reaction / inflation weight
phi_y_LR  = 0;      % long-run output gap change reaction / output gap change weight
phi_yg_LR = 0;      % long-run output gap reaction / output gap weight
phi_o_LR  = 0;      % long-run oil price level reaction / oil price level weight
phi_oc_LR = 0;      % long-run oil price change reaction / oil price change weight
phi_R	  =	0.6; % Interest rate smoothing parameter

beta      = 1.03^-.25;        % discount factor
PI_bar    = 1;                % steady state inflation      
R_bar     = PI_bar/beta;      % steady state nominal interest rate

psi       =	1;                % Frisch elasticity   (utility function)
gamma     = 0.32;             % capital elasticity  (production function)
alpha     = 1-gamma-0.05;     % oil elasticity      (production function)

theta	  =	0.6;                 % Calvo for prices
epsilon   = 7.66;                % alasticity
mu        = epsilon/(epsilon-1); % mamrkup

A         = 1;          % Productivity in steady state
Z         = 1;          % Oil technology in steady state
K_ss      = 1;
X_O       = 3/2;        % maximum production of Fringe Oil producers (Capacity constraint)

% xi(i) \in U(a,b) distribution of individual productivity for fringe producers in comparison to OPEC
aa        = 0;
bb        = 1;          


% Flexibe price equilibrium
Lf_ss    = (alpha/(mu-(1-alpha-gamma)))^(1/(1+psi));                         % Labor supply
pof_ss   = (1+X_O*(1+alpha+gamma))/((1-alpha-gamma)+ X_O*(1+alpha+gamma));   % SS real price of oil
Of_ss    = (pof_ss*mu/((1-alpha-gamma)*Lf_ss))^(-1/(alpha+gamma))/(1+X_O);   % Oil prduction OPEC
Omeg_fss = X_O*Of_ss/(bb*(pof_ss-aa));                                       % Oil production ROW

% shock persistence parameters

rho_a     = 0.95;     % productivity shock
rho_z     = 0.70;     % oil technology shock
rho_x     = 0.80;     % non-opec capacity
rho_zb	  =	0;
rho_r     = 0;

% standard deviation of shocks
stderrea  = 0.7;
stderrez  = 10;
stderrex  = 10;
stderrezb =	0.7;
stderrer  = 0.1;     

% pre-solving the steady-state
X_ss = fsolve('EOil_do_SS', [1.45, 0],[],'zerofinder');
[X_ss,SScheck]=EOil_do_SS(X_ss,'monopolist');              

% retrieving necessary steady-state values
pomu_ss = X_ss(3);         % ratio of oil prices (monopoly / no-monopoly)
SO_ss   = X_ss(9);         % share of OPEC in production
po_ss   = X_ss(17);        % oil price
Cgap_ss = X_ss(26);        % ratio of oil prices (monopoly / no-monopoly)

model;
# phi_p     = phi_p_LR*(1-phi_R);    % short-run inflation coefficient
# phi_y     = phi_y_LR*(1-phi_R);    % short-run output gap change coefficient
# phi_yg    = phi_yg_LR*(1-phi_R);   % short-run output gap coefficient
# phi_o     = phi_o_LR*(1-phi_R);    % short-run oil price level coefficient
# phi_oc    = phi_oc_LR*(1-phi_R);   % short-run oil price change coefficient

// 1. Value function of US
V_IMP = log(C) - L^(1+psi)/(1+psi) + beta*V_IMP(+1);  

// 2. Value function of OPEC
V_EXP  = log(O*(po-poe)) + beta*V_EXP(+1);

// 3. Markup on oil price by OPEC
pomu = po/poe;

// 4. Market shahre of OPEC
SO = O/(XX+O);

// 5. Production of oil of fringe producers, eq. 19
XX = bb*(po*exp(zz)-aa)*exp(x)*Omeg_fss;

// 6. Consumption in US, global resource constraint, eq. 30
C = Y - po*(O + XX);

// 7. MRS, Real wage in US, eq. 20
w = C*L^psi;

//. 8. Euler equation, eq. 21
1 = beta*R*exp(zb(+1))*C/C(+1)/exp(zb)/PI(+1);

// 9. Sticky price block, eqs. 22-25
D = exp(zb)*Y/C + beta*theta*PI_bar*PI(+1)^(epsilon-1)*D(+1);
N = mu*mc*exp(zb)*Y/C + beta*theta*PI(+1)^epsilon*N(+1);
1 = theta*(PI/PI_bar)^(epsilon-1) + (1-theta)*(N/D)^(1-epsilon);
DP = theta*(PI/PI_bar)^epsilon*DP(-1) + (1-theta)*(N/D)^(-epsilon);

// 10. FOC, Demand for oil, eq. 26
po*(O + XX) = (1-alpha-gamma)*mc*Y*DP;

// 11. FOC, demand for labor, eq. 27
w*L = alpha*mc*Y*DP;

// 12. Goods market equilibrium, eq. 28
Y*DP = exp(a)*L^alpha*K_ss^gamma*(O + XX)^(1-alpha-gamma);

// 13. Interest rate rule, eq. 29                                                                                                            
phi_i*(R-R_bar)= phi_i*(R(-1)-R_bar)*phi_R + (PI-1)*phi_p + (C-Ce-(C(-1)-Ce(-1)))*phi_y + 
                 + (C/Ce-Cgap_ss)*phi_yg + (po-po_ss)*phi_o + (po-po(-1))*phi_oc +rr; 

// eqs. 31 - 42
0 = 1/O  - L1*po - L7*po + L9*(1-alpha-gamma)*Y*DP/(O + XX);

0 = - L1*C + L2 - L2(-1)*R(-1)*C(-1)/C/PI - L3*Y -L4*mu*mc*Y + L10*w + (L11-beta*L11(+1))*phi_y*C
      + L11*phi_yg*C/Ce;

0 =  L1 + L3*exp(zb) + L4*mu*mc*exp(zb) + L7*(1-alpha-gamma)*mc*DP - L8*alpha*mc*DP - L9*DP;

0 = L3(-1)*theta*PI_bar*C(-1)*PI^(epsilon-1) - L3*C + L5*(1-theta)*(epsilon-1)*N^(1-epsilon)*D^(epsilon-2) 
    + L6*(1-theta)*epsilon*N^(-epsilon)*D^(epsilon-1);

0 = L4(-1)*theta*C(-1)*PI^(epsilon) - L4*C + L5*(1-theta)*(1-epsilon)*N^(-epsilon)*D^(epsilon-1)
    - L6*(1-theta)*epsilon*N^(-epsilon-1)*D^epsilon;

0 = L8*w + L9*alpha*Y*DP/L + L10*C*psi*L^(psi-1);

0 = 1/(po - 1/exp(zz)) - (O + 2*XX)*(L1 + L7) + L9*(1-alpha-gamma)*Y*DP/(O + XX)*exp(zz)*exp(x)*Omeg_fss*bb
    +  phi_o*L11 + phi_oc*(L11-beta*L11(+1)) ; 

0 = -L2(-1)*R(-1)*C(-1)/C/PI^2 + L3(-1)*theta*PI_bar*(epsilon-1)*C(-1)*PI^(epsilon-2)*D 
   + L4(-1)*theta*epsilon*C(-1)*PI^(epsilon-1)*N + L5*theta*(epsilon-1)*PI^(epsilon-2)*PI_bar^(1-epsilon) 
   + L6*theta*epsilon*PI_bar^(-epsilon)*PI^(epsilon-1)*DP(-1)
   + L11*phi_p;

0 = L6(+1)*beta*theta*(PI(+1)/PI_bar)^epsilon - L6 + L7*(1-alpha-gamma)*mc*Y - L8*alpha*mc*Y - L9*Y;

0 = L4*mu*exp(zb) + L7*(1-alpha-gamma)*DP - L8*alpha*DP;

0 = L2/R - phi_i*(L11 - phi_R*beta*L11(+1));

0 = L8*L - L10;

// Definitions, comparison to a market without a monopoly of OPEC

// Oil production, fringe oil producers
Xe = bb*(poe*exp(zz)-aa)*exp(x)*Omeg_fss;

// pdemand for oil
poe*(Oe + Xe) = (1-alpha-gamma)/mu*Ye;

// price of oil
poe = 1/exp(zz);

// production, US
Ye = exp(a)*Lf_ss^alpha*K_ss^gamma*(Oe+Xe)^(1-alpha-gamma);

// Consumption, US
Ce = Ye*(1-(1-alpha-gamma)/mu);
Ygap = Y/Ye;
Cgap = C/Ce;

// shock processes
a  = rho_a*a(-1) + 0.01*stderrea*ea;
zz = rho_z*zz(-1) - 0.01*stderrez*ez;
x  = rho_x*x(-1) - 0.01*stderrex*ex;
rr = rho_r*rr(-1) - 0.01*stderrer*er;
zb = rho_zb*zb(-1) + 0.01*stderrezb*ezb;

// observables
y_obs    = 100*log(C/C(-1)) + mu_y;           // GDP QoQ     
p_obs    = 100*log(PI) + mu_p;                // CPI QoQ     
R_obs    = 400*(R - 1/beta) + mu_R;            // Interest rate 
oil_obs  = 100*log(po/po(-1)) + mu_oil;       // real price of oil

// OPEC profits
profit = O*(po-poe);
end;

shocks;
var ea;     stderr 1;
var ez;     stderr 1;
var ex;     stderr 1;
var er;     stderr 1;
var ezb;    stderr 1;
end;

initval;
    V_IMP     =	    X_ss(1);
    V_EXP     =	    X_ss(2);
    pomu      =     X_ss(3);
    profit    = 	X_ss(4);
    R_obs     = 	X_ss(5);
    p_obs     = 	X_ss(6);
    y_obs     = 	X_ss(7);
    oil_obs   = 	X_ss(8);
    SO        = 	X_ss(9);
    XX        = 	X_ss(10);
    Y         = 	X_ss(11);
    C         = 	X_ss(12);
    L         = 	X_ss(13);
    O         = 	X_ss(14);
    D         = 	X_ss(15);
    N         = 	X_ss(16);
    po        = 	X_ss(17);
    w         = 	X_ss(18);
    PI        = 	X_ss(19);
    R         = 	X_ss(20);
    DP        = 	X_ss(21);
    mc        = 	X_ss(22);
    Ygap      = 	X_ss(23);
    Ye        = 	X_ss(24);
    Ce        = 	X_ss(25);
    Cgap      = 	X_ss(26);
    Oe        = 	X_ss(27);
    Xe        = 	X_ss(28);
    poe       = 	X_ss(29);
    L1        = 	X_ss(30);
    L2        = 	X_ss(31);
    L3        = 	X_ss(32);
    L4        = 	X_ss(33);
    L5        = 	X_ss(34);
    L6        = 	X_ss(35);
    L7        = 	X_ss(36);
    L8        = 	X_ss(37);
    L9        = 	X_ss(38);
    L10       = 	X_ss(39);
    L11       = 	X_ss(40);
    a         = 	X_ss(41);
    zz        = 	X_ss(42);
    x         = 	X_ss(43);
    rr        = 	X_ss(44);
    zb        = 	X_ss(45);
end;

steady;
check;

// use next line for IRFs
// stoch_simul(order=1, irf=20) po O XX SO Y PI R;

estimated_params;
mu_y,                   uniform_pdf, , , 0, 10;  // mean, std, min, max
mu_p,                   uniform_pdf, , , 0, 10;
mu_R,                   uniform_pdf, , , 0, 20;
mu_oil,                 uniform_pdf, , , -10, 10;
theta,   0.60, 0, 0.99, beta_pdf, 0.60, 0.10;
psi,                    gamma_pdf, 1.0, 0.25; 
phi_R,                  normal_pdf, 0.6, 0.1; 
phi_p_LR,               normal_pdf, 1.5, 0.5; 
phi_yg_LR,              normal_pdf, 0.5, 0.125; 
rho_a,   0.90, 0, 0.99, beta_pdf, 0.90, 0.05;
rho_z,   0.90, 0, 0.99, beta_pdf, 0.90, 0.05;
rho_x,   0.90, 0, 0.99, beta_pdf, 0.90, 0.05;
rho_zb,  0.90, 0, 0.99, beta_pdf, 0.90, 0.05;
stderrea,              inv_gamma_pdf, 0.7, Inf;
stderrez,              inv_gamma_pdf, 10, Inf;
stderrex,              inv_gamma_pdf, 10, Inf;
stderrezb,             inv_gamma_pdf, 0.7, Inf;
stderrer,              inv_gamma_pdf, 0.1, Inf;
end;

varobs y_obs p_obs R_obs oil_obs;

load options_est;
estimation(datafile=data,plot_priors=0, prefilter=0, mode_file=NPmodel_mode, mode_compute=0,mh_nblocks=4,mh_replic=62500,mh_jscale=0.40,mh_drop=0.2,first_obs=1) y_obs p_obs R_obs oil_obs;
stoch_simul(irf=0,order=1) y_obs p_obs R_obs oil_obs;

