% A script to calculate:
% forecasts
% actuals
% PITs
% Predictive Likelihood
% for all variables and methods

% results:
% Object ALLfct

clear all
clc
format compact

modelNames = [{'RW'} {'BARfixed'} {'SDBVAR'} {'SLBVAR'} {'LDBVAR'} {'LLBVAR'} {'LMBVAR'} {'DSGE'} {'DSGEnt'}];
cntryNames = [{'AUS'} {'CAD'} {'UK'} {'EA'} {'US'}];

H  = 24;                    % forecast horizon
T  = 156;                   % total number of observations
T0 = 81;                    % observation for 95q1 (so that data(T0) refers to 95q1
varnames = [{'q_obs'} {'ca_obs'} {'ner_obs'} {'p_obs'} {'p_s_obs'}];

N  = size(varnames,2);      % number of variables
    
    
for cN=1:size(cntryNames,2)
display(cntryNames{cN})  
cName = cntryNames{cN};
for mN=10 %1:size(modelNames,2)
    display(modelNames{mN})
    mName = modelNames{mN};
    
    % loads actuals
    copyfile(['data_',cName,'.mat'],'data_actuals.mat');
    load(['data_actuals']);
        
    % initializes matrices for growth rates and levels
    for n = 1:N
        vnm = varnames{n};
        eval(['ALLtemp.',vnm,'.act    = NaN(T-T0+1,H);'])
        eval(['ALLtemp.',vnm,'.fct    = NaN(T-T0+1,H);']) % Adolfson method
        eval(['ALLtemp.',vnm,'.pit    = NaN(T-T0+1,H);'])
        eval(['ALLtemp.',vnm,'.pLL    = NaN(T-T0+1,H);'])
    end
    
    % main loop for each periods generates draws and calculates forecasts,
    % actuals, predictive Likelihhod and PITs
    for i = 95:113 
        for j = 1:4
                    
        Tf    = T0 + 4*(i-95) + (j-1) ;                                % moment of forecast formulation
        fname = [mName,'/',cName,'/',num2str(i),'q',num2str(j),'/forecasts.mat'];  
        if ~exist(fname,'file')
            continue;
        end
        load(fname);                                                  % loads forecast draws  
                
        % individual variables
        for n = 1:N 
            vnm = varnames{n};
            
            act  = NaN(1,H); % actuals
            pit  = NaN(1,H); % PIT, Adolfson
            pLL  = NaN(1,H); % predictive scores, Adolfson
            
            if n > 2 && mN<5 % general case
                draws=NaN(H,1);        % forecast for NER equal to forecast for RER  
            else                       
                eval(['draws=f.',vnm,';']);      % forecast draws             
            end
            fct      = (mean(draws,2))';        % point forecasts (mean), Adolfson
                        
            % check if actuals exists and calculate actuals
            Hf    = H;
            if Tf+H > T; Hf = T-Tf+1; end
            eval(['act(1:Hf)=',vnm,'(Tf:(Tf+Hf-1));']); 
            if n ~= 2 % n==2 for CA
                act = cumsum(act);
            end
            
            % calculate PIT and predictive density
            for h = 1:Hf
                pit(h)       = PIT(draws(h,:),act(h));
                pLL(h)       = PredLL(draws(h,:),act(h));
            end
                 
            % Saves results          
            eval(['ALLtemp.',vnm,'.act(Tf-T0+1,:)    = act;'])
            eval(['ALLtemp.',vnm,'.fct(Tf-T0+1,:)    = fct;'])
            eval(['ALLtemp.',vnm,'.pLL(Tf-T0+1,:)    = pLL;'])
            eval(['ALLtemp.',vnm,'.pit(Tf-T0+1,:)    = pit;'])
        end    
         
    end
    end
ALLfct{cN,mN} = ALLtemp;   
ALLfct{cN,mN}.cName = cName;
ALLfct{cN,mN}.mName = mName;
end
end
save(['ALLfct.mat'], 'ALLfct');   
 



